{
-----------------------------------------------------------------
Code generated with MAS Component Wizard, 2000-2003 MASoft
-----------------------------------------------------------------

Component Name: TmLog
        Author: MASoft, Mats Asplund
 Creation Date: 2004-01-11
       Version: 1.2
   Description: A logfile component.
        E-mail: mdp@telia.com
       Website: http://hem.passagen.se/matasp
  Legal Issues: All rigths reserved 2004 by Mats Asplund


Usage:
  This software is provided 'as-is', without any express or
  implied warranty.  In no event will the author be held liable
  for any  damages arising from the use of this software.

  Permission is granted to anyone to use this software for any
  purpose, including commercial applications, and to alter it
  and redistribute it freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented,
     you must not claim that you wrote the original software.
     If you use this software in a product, an acknowledgment
     in the product documentation would be appreciated but is
     not required.

  2. Altered source versions must be plainly marked as such, and
     must not be misrepresented as being the original software.

  3. This notice may not be removed or altered from any source
     distribution.

  4. If you decide to use this software in any of your applications.
     Send me an EMail and tell me about it.

Quick Reference:
  TmLog inherits from TComponent

  Key-Properties:
    LogFileName: Name of the logfile that is to be used.

    TraceLevelRegKeyValue: The registry key value where the trace level is kept.
                           Writing to this property will create a new registry
                           key.

    TraceLevel: Trace level that are kept in registry. Writing to this property
                will change the value at TraceLevelRegKeyValue in Registry.
                If you want to change tracelevel for a running application,
                patch directly in registry.
                Could be (0-2):
                mtrcOperation (0) - all AddToLog methods from your appl. with
                  severity levels msevOperation and msevException will be
                  written to log.
                mtrcOperationDetail (1) - all AddToLog methods from your appl.
                  will be written to log.
                mtrcException (2) - only AddToLog methods with severity level
                  msevException will be written to log.

    ShowSeverityLevelInLog: If true the severity level will be written to log,
                            along with each record.

  Key-Methods:
    AddToLog(Msg: string; SeverityLevel: TmSeverityLevel) : Place this method
      in your code where you want logging. Msg is the log text.
      Severity levels: msevOperation, msevOperationDetail, msevException

---------------------------------------------------------------
}

unit mLog;

interface

uses
  Windows, Messages, SysUtils, Classes, Forms, Registry;

type
  TmSeverityLevel = (msevOperation, msevOperationDetail, msevException);

  TmTraceLevel = (mtrcOperation, mtrcOperationDetail, mtrcException);

  TmLog = class(TComponent)
  private
    fAbout: string;
    fLogFileName: TFileName;
    fTraceLevel: TmTraceLevel;
    fTraceLevelRegKeyValue: string;
    fShowSeverityLevelInLog: boolean;
    procedure SetAbout(Value: string);
    procedure SetTraceLevel(const Value: TmTraceLevel);
    procedure SetLogFileName(const Value: TFileName);
    procedure SetTraceLevelRegKeyValue(const Value: string);
  protected
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure AddToLog(Msg: string; SeverityLevel: TmSeverityLevel);
  published
    property LogFileName: TFileName read fLogFileName write SetLogFileName;
    property ShowSeverityLevelInLog: boolean read fShowSeverityLevelInLog
      write fShowSeverityLevelInLog;
    property TraceLevel: TmTraceLevel read fTraceLevel write SetTraceLevel;
    property TraceLevelRegKeyValue: string read fTraceLevelRegKeyValue
      write SetTraceLevelRegKeyValue;
    property About: string read fAbout write SetAbout;
  end;

procedure Register;

implementation

constructor TmLog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  LogFileName:= 'default.log';
  TraceLevelRegKeyValue:= '\software\masprod\logs\tracelevels';
  TraceLevel:= mtrcOperation;
  fAbout:= 'Version 1.0, 2004 MASoft';
end;

destructor TmLog.Destroy;
begin
  inherited Destroy;
end;

procedure TmLog.AddToLog(Msg: string; SeverityLevel: TmSeverityLevel);
var
  F: TextFile;
begin
  case SeverityLevel of
    msevOperation:
      if (Ord(TraceLevel) = 0) or (Ord(TraceLevel) = 1) then
      begin
        if ShowSeverityLevelInLog then
          Msg:= DateTimeToStr(Now) + ' [Operation] ' + Msg
        else
          Msg:= DateTimeToStr(Now) + ' ' + Msg;
      end
      else
        Exit;
    msevOperationDetail:
      if (Ord(TraceLevel) = 1) then
      begin
        if ShowSeverityLevelInLog then
          Msg:= DateTimeToStr(Now) + ' [OperationDetail] ' + Msg
        else
          Msg:= DateTimeToStr(Now) + ' ' + Msg;
      end
      else
        Exit;
    msevException:
        if ShowSeverityLevelInLog then
          Msg:= DateTimeToStr(Now) + ' [Exception] ' + Msg
        else
          Msg:= DateTimeToStr(Now) + ' ' + Msg;
  end;

  if not FileExists(LogFileName) then
  begin
    AssignFile(F, LogFileName);
    Rewrite(F);
  end
  else
  begin
    AssignFile(F, LogFileName);
    Append(F);
  end;
  Writeln(F, Msg);
  Flush(F);
  CloseFile(F);
end;

procedure TmLog.SetAbout(Value: string);
begin
  Exit;
end;

procedure TmLog.SetLogFileName(const Value: TFileName);
begin
  fLogFileName := Value;
  SetTraceLevel(fTraceLevel);
end;

procedure TmLog.SetTraceLevel(const Value: TmTraceLevel);
var
  Reg: TRegistry;
begin
  Reg:= TRegistry.Create;
  try
    fTraceLevel:= Value;
    with Reg do
    begin
      RootKey:= HKEY_LOCAL_MACHINE;
      OpenKey(TraceLevelRegKeyValue, true);
      WriteInteger(LogFileName, Ord(Value));
      CloseKey;
    end;
  finally
    Reg.Free;
  end;
end;

procedure Register;
begin
  RegisterComponents('MASoft', [TmLog]);
end;

procedure TmLog.SetTraceLevelRegKeyValue(const Value: string);
var
  Reg: TRegistry;
begin
  Reg:= TRegistry.Create;
  try
    fTraceLevelRegKeyValue := Value;
    with Reg do
    begin
      RootKey:= HKEY_LOCAL_MACHINE;
      OpenKey(fTraceLevelRegKeyValue, true);
      WriteInteger(LogFileName, Ord(fTraceLevel));
      CloseKey;
    end;
  finally
    Reg.Free;
  end;
end;

end.

